# jailbase
python lib for https://www.jailbase.com/api/

## Lib Usage
Example usage of library can be found in cli.py


## Example Cli Usage

``` sh
jailbase --help

jailbase recent al-ccsd --log-level debug --cache cache --limit 5 --exclude id,charges,more_info_url,details
```

